==> 0.0.7.tar.gz: lib/storebounty_auth_v1.dart <==
library storebounty_auth;

import 'dart:convert';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:storebounty_init/api/httpclient.dart';
import 'package:storebounty_init/storebountyinit.dart';

export 'src/screens/authentry.dart';

class StorebountyAuth {

  static Future LoginUser(body) async {
    try {

      var storeId = await StoreBountyInit.getStoreId();

      var data = {
        "app_id": "storebounty",
        "business_id": storeId,
        "username": body['email'],
        "password": body['password'],
        "platform": "mobile",
        "fingerprint": {
          "id": "123",
          "model": "SM-G970U1",
          "os_version": 11,
          "screen_width": 360,
          "screen_height": 760,
          "manufacturer": "samsung",
          "is_physical_device": true,
          "screen_resolution": "1080x2280",
          "ip": "107.181.180.171"
        }
      };

      final response = await HttpClientClass.postRequestAuth("https://apis-dev.ibunchng.com/accounts/api/v1/auth/customers/token", data);

      print(response.body);
      if (response.statusCode == 200) {

        await _saveLoginRecord(response);
        return response;
      } else if (response.statusCode == 401) {
        var error = jsonDecode(response.body);
        throw (error['data']['message']);
      }
      else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['message']);
      }else if(response.statusCode == 422){
        var error = jsonDecode(response.body);
        throw (error["msg"]);
      } else {
        throw ("Unknown error");
      }
    } catch (e) {
      rethrow;
    }
  }

  static Future register(body) async {
    try {

      var storeId = await StoreBountyInit.getStoreId();

      var data = {
        "app_id": "storebounty",
        "business_id": storeId,
        "email": body['email'],
        "first_name": body['first_name'],
        "last_name": body['last_name'],
        "phone": body['phone'],
        "password": body['password'],
        // "platform": "mobile",
        // "firebase_device_id": "HGHFTYUYJLKJ778GHJG6456VHJ",
        "fingerprint": {
          // "id": "123",
          // "model": "SM-G970U1",
          // "os_version": 11,
          // "screen_width": 360,
          // "screen_height": 760,
          // "manufacturer": "samsung",
          // "is_physical_device": true,
          // "screen_resolution": "1080x2280",
          // "firebase_device_token": "HGHFTYUYJLKJ778GHJG6456VHJ",
          // "ip": "107.181.180.171"
        }
      };

      final response = await HttpClientClass.postRequestAuth("https://apis-dev.ibunchng.com/accounts/api/v1/auth/customers/register", data);

      print(response.body);

      if (response.statusCode == 200) {
        return response;
      } else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['message']);
      } else {
        throw ("Unknown error");
      }

    } catch (e) {
      rethrow;
    }
  }

  static Future sendResetPasswordOtp(body) async {
    try {

      var storeId = await StoreBountyInit.getStoreId();

      var data = {
        "app_id": "storebounty",
        "business_id": storeId,
        "email": body['email']
      };

      final response = await HttpClientClass.postRequestAuth("https://apis-dev.ibunchng.com/accounts/api/v1/auth/customers/otp/send", data);

      print(response.body);

      if (response.statusCode == 200) {
        return response;
      } else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['message']);
      } else {
        throw ("Unknown error");
      }

    } catch (e) {
      rethrow;
    }
  }

  static Future resetPassword(body) async {
    try {

      var storeId = await StoreBountyInit.getStoreId();

      var data = {
        "app_id": "storebounty",
        "email": body['email'],
        "business_id": storeId,
        "otp": body['otp'],
        "new_password": body['new_password'],
        "repeat_password": body['repeat_password']
      };

      final response = await HttpClientClass.postRequestAuth("https://apis-dev.ibunchng.com/accounts/api/v1/auth/customers/password/reset", data);

      print(response.body);

      if (response.statusCode == 200) {
        return response;
      } else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['data']['message']);
      } else {
        throw ("Unknown error");
      }
    } catch (e) {
      rethrow;
    }
  }

  static _saveLoginRecord(response)async{

    final SharedPreferences prefs = await SharedPreferences.getInstance();

    var dataGotten = jsonDecode(response.body);

    await prefs.setString("token", dataGotten['token']);
    await prefs.setString("user", jsonEncode(dataGotten['data']['customer']));

    print(dataGotten['data']['customer']['first_name']);

  }

  static getUser()async{

    final SharedPreferences prefs = await SharedPreferences.getInstance();

    var data = prefs.getString("user");

    if(data == null) return null;

    return jsonDecode(data);
  }

  static Future checkIfUserIsLoggedIn()async{

    final SharedPreferences prefs = await SharedPreferences.getInstance();

    var token = prefs.getString("token");

    return token;

  }

  Future verifyEmail(body) async {
    try {
      final response = await HttpClientClass.postRequestAuthOrder("https://apis-dev.ibunchng.com/accounts/api/v1/customers/email/verify", body);

      print(response.body);

      if (response.statusCode == 200) {
        return response;
      } else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['message']);
      } else {
        throw ("Unknown error");
      }

    } catch (e) {
      rethrow;
    }
  }

  static Future logOut()async{

    final SharedPreferences prefs = await SharedPreferences.getInstance();

    await prefs.remove("token");
    await prefs.remove("user");
    return {"status": true, "message":"Logout successful"};

  }

}

==> 0.1.0-dev.tar.gz: lib/storebounty_auth_v1.dart <==
library storebounty_auth;

import 'dart:convert';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:storebounty_init/api/httpclient.dart';
import 'package:storebounty_init/storebountyinit.dart';

export 'src/screens/authentry.dart';

class StorebountyAuth {

  static Future LoginUser(body) async {
    try {

      var storeId = await StoreBountyInit.getStoreId();
      final jsonData = await StoreBountyInit.readJsonFromRoot();

      var data = {
        "app_id": "storebounty",
        "business_id": storeId,
        "username": body['email'],
        "password": body['password'],
        "platform": "mobile",
        "fingerprint": {
          "id": "123",
          "model": "SM-G970U1",
          "os_version": 11,
          "screen_width": 360,
          "screen_height": 760,
          "manufacturer": "samsung",
          "is_physical_device": true,
          "screen_resolution": "1080x2280",
          "ip": "107.181.180.171"
        }
      };

      final response = await HttpClientClass.postRequestAuth("${jsonData['BASE_URL']}/accounts/api/v1/auth/customers/token", data);

      print(response.body);
      if (response.statusCode == 200) {
        
        // await _saveLoginRecord(response);
        return response;
      } else if (response.statusCode == 401) {
        var error = jsonDecode(response.body);
        throw (error['data']['message']);
      }
      else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['message']);
      }else if(response.statusCode == 422){
        var error = jsonDecode(response.body);
        throw (error["msg"]);
      } else {
        throw ("Unknown error");
      }
    } catch (e) {
      rethrow;
    }
  }

  static Future register(body) async {
    try {

      var storeId = await StoreBountyInit.getStoreId();
      final jsonData = await StoreBountyInit.readJsonFromRoot();

      var data = {
        "app_id": "storebounty",
        "business_id": storeId,
        "email": body['email'],
        "first_name": body['first_name'],
        "last_name": body['last_name'],
        "phone": body['phone'],
        "password": body['password'],
        // "platform": "mobile",
        // "firebase_device_id": "HGHFTYUYJLKJ778GHJG6456VHJ",
        "fingerprint": {
          // "id": "123",
          // "model": "SM-G970U1",
          // "os_version": 11,
          // "screen_width": 360,
          // "screen_height": 760,
          // "manufacturer": "samsung",
          // "is_physical_device": true,
          // "screen_resolution": "1080x2280",
          // "firebase_device_token": "HGHFTYUYJLKJ778GHJG6456VHJ",
          // "ip": "107.181.180.171"
        }
      };

      final response = await HttpClientClass.postRequestAuth("${jsonData['BASE_URL']}/accounts/api/v1/auth/customers/register", data);

      print(response.body);

      if (response.statusCode == 200) {
        _saveLoginRecord(response);
        return response;
      } else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['message']);
      } else {
        throw ("Unknown error");
      }

    } catch (e) {
      rethrow;
    }
  }

  static Future sendResetPasswordOtp(body) async {
    try {

      var storeId = await StoreBountyInit.getStoreId();
      final jsonData = await StoreBountyInit.readJsonFromRoot();

      var data = {
        "app_id": "storebounty",
        "business_id": storeId,
        "email": body['email']
      };

      final response = await HttpClientClass.postRequestAuth("${jsonData['BASE_URL']}/accounts/api/v1/auth/customers/otp/send", data);

      print(response.body);

      if (response.statusCode == 200) {
        return response;
      } else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['message']);
      } else {
        throw ("Unknown error");
      }

    } catch (e) {
      rethrow;
    }
  }

  static Future resetPassword(body) async {
    try {

      var storeId = await StoreBountyInit.getStoreId();
      final jsonData = await StoreBountyInit.readJsonFromRoot();

      var data = {
        "app_id": "storebounty",
        "email": body['email'],
        "business_id": storeId,
        "otp": body['otp'],
        "new_password": body['new_password'],
        "repeat_password": body['repeat_password']
      };

      final response = await HttpClientClass.postRequestAuth("${jsonData['BASE_URL']}/accounts/api/v1/auth/customers/password/reset", data);

      print(response.body);

      if (response.statusCode == 200) {
        return response;
      } else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['data']['message']);
      } else {
        throw ("Unknown error");
      }
    } catch (e) {
      rethrow;
    }
  }

  static _saveLoginRecord(response)async{

    final SharedPreferences prefs = await SharedPreferences.getInstance();

    var dataGotten = jsonDecode(response.body);

    await prefs.setString("token", dataGotten['token']);
    await prefs.setString("user", jsonEncode(dataGotten['data']['customer']));

    print(dataGotten['data']['customer']['first_name']);

  }

  static getUser()async{

    final SharedPreferences prefs = await SharedPreferences.getInstance();

    var data = prefs.getString("user");

    if(data == null) return null;

    return jsonDecode(data);
  }

  static Future checkIfUserIsLoggedIn()async{

    final SharedPreferences prefs = await SharedPreferences.getInstance();

    var token = prefs.getString("token");

    return token;

  }

  Future verifyEmail(body) async {
    try {

      final jsonData = await StoreBountyInit.readJsonFromRoot();
      
      final response = await HttpClientClass.postRequestAuthOrder("${jsonData['BASE_URL']}/accounts/api/v1/customers/email/verify", body);

      print(response.body);

      if (response.statusCode == 200) {
        return response;
      } else if (response.statusCode == 412) {
        var error = jsonDecode(response.body);
        throw (error['message']);
      } else {
        throw ("Unknown error");
      }

    } catch (e) {
      rethrow;
    }
  }

  static Future logOut()async{

    final SharedPreferences prefs = await SharedPreferences.getInstance();

    await prefs.remove("token");
    await prefs.remove("user");
    return {"status": true, "message":"Logout successful"};

  }

}
